@@ -27,7 +27,11 @@
 #'  (The singular value is symmetrically partitioned into the genotype and the environment eigenvectors
 #'  This SVP is most often used in AMMI analysis and other biplot analysis, but it is not ideal for
 #'  visualizing either the relationship among genotypes or that among the environments).
-#'
+#' @param by One variable (factor) to compute the function by. It is a shortcut
+#'   to \code{\link[dplyr]{group_by}()}.This is especially useful, for example,
+#'   when the researcher want to produce GGE biplots for each level of a
+#'   categorical variable. In this case, an object of class gge_grouped is
+#'   returned.
 #' @param ... Arguments passed to the function
 #'   \code{\link{impute_missing_val}()} for imputation of missing values in case
 #'   of unbalanced data.
@@ -94,7 +98,27 @@ gge <- function(.data,
                 centering = "environment",
                 scaling = "none",
                 svp = "environment",
+                by = NULL,
                 ...) {
+  if (!missing(by)){
+    if(length(as.list(substitute(by))[-1L]) != 0){
+      stop("Only one grouping variable can be used in the argument 'by'.\nUse 'group_by()' to pass '.data' grouped by more than one variable.", call. = FALSE)
+    }
+    .data <- group_by(.data, {{by}})
+  }
+  if(is_grouped_df(.data)){
+      results <-
+        .data %>%
+        doo(gge,
+            env = {{env}},
+            gen = {{gen}},
+            resp = {{resp}},
+            centering = centering,
+            scaling = scaling,
+            svp = svp,
+            ...)
+      return(set_class(results, c("tbl_df",  "gge_group", "tbl",  "data.frame")))
+    } else{
   factors  <-
     .data %>%
     select({{env}}, {{gen}}) %>%
@@ -210,15 +234,12 @@ gge <- function(.data,
     }
   }
   return(structure(listres, class = "gge"))
+    }
 }
 
 
 
 
-
-
-
-
 #' Create GGE, GT or GYT biplots
 #'
 #' Produces a ggplot2-based GGE-GT-GYT biplot based on a model fitted with the
@@ -250,15 +271,19 @@ gge <- function(.data,
 #'   \code{shape.env = 23} (rhombus) for environments. Values must be between
 #'   \code{21-25}: \code{21} (circle), \code{22} (square), \code{23} (rhombus),
 #'   \code{24} (up triangle), and \code{25} (low triangle).
+#' @param line.type.gen The line type to highlith the genotype's vectors.
+#'   Defaults to `line.type.gen == "dotted`.
 #' @param size.shape The size of the shape (both for genotypes and
 #'   environments). Defaults to \code{2.2}.
 #' @param size.shape.win The size of the shape for winners genotypes when
 #'   \code{type = 3}. Defaults to \code{3.2}.
-#' @param size.bor.tick The size of tick of shape. Default is \code{0.3}. The
-#'   size of the shape will be \code{size.shape + size.bor.tick}
-#' @param col.gen,col.env Color for genotype and environment attributes in the
-#'   biplot. Defaults to \code{col.gen = 'blue'} and \code{col.env =
-#'   'forestgreen'}
+#' @param size.stroke,col.stroke The width and color of the border,
+#'   respectively. Default to \code{size.stroke = 0.3} and \code{col.stroke =
+#'   "black"}. The size of the shape will be \code{size.shape + size.stroke}
+#' @param col.gen,col.env,col.line Color for genotype/environment labels and for
+#'   the line that passes through the biplot origin. Defaults to \code{col.gen =
+#'   'blue'}, \code{col.env = 'forestgreen'}, and \code{col.line =
+#'   'forestgreen'}.
 #' @param col.alpha The alpha value for the color. Defaults to \code{1}. Values
 #'   must be between \code{0} (full transparency) to \code{1} (full color).
 #' @param col.circle,col.alpha.circle The color and alpha values for the circle
@@ -266,10 +291,12 @@ gge <- function(.data,
 #' @param leg.lab The labs of legend. Defaults to \code{NULL} is \code{c('Env', 'Gen')}.
 #' @param size.text.gen,size.text.env,size.text.lab The size of the text for
 #'   genotypes, environments and labels, respectively.
+#' @param size.text.win The text size to use for winner genotypes where
+#'   \code{type = 3} and for the two selected genotypes where \code{type = 9}.
+#'   Defaults to 4.5.
 #' @param size.line The size of the line in biplots (Both for segments and circles).
-#' @param large_label The text size to use for larger labels where \code{type =
-#'   3}, used for the outermost genotypes and where \code{type = 9}, used for
-#'   the two selected genotypes. Defaults to 4.5
+#' @param large_label Deprecated as of metan 1.11.0. Use \code{size.text.win}
+#'   instead.
 #' @param axis_expand multiplication factor to expand the axis limits by to
 #'   enable fitting of labels. Defaults to 1.2
 #' @param title Logical values (Defaults to \code{TRUE}) to include
@@ -307,11 +334,14 @@ plot.gge <- function(x,
                      sel_gen2 = NA,
                      shape.gen = 21,
                      shape.env = 23,
+                     line.type.gen = "dotted",
                      size.shape = 2.2,
                      size.shape.win = 3.2,
-                     size.bor.tick = 0.3,
+                     size.stroke = 0.3,
+                     col.stroke = "black",
                      col.gen = "blue",
                      col.env = "forestgreen",
+                     col.line = "forestgreen",
                      col.alpha = 1,
                      col.circle = "gray",
                      col.alpha.circle = 0.5,
@@ -319,13 +349,17 @@ plot.gge <- function(x,
                      size.text.gen = 4,
                      size.text.env = 4,
                      size.text.lab = 12,
+                     size.text.win = 4.5,
                      size.line = 0.5,
-                     large_label = 4.5,
+                     large_label = "deprecated",
                      axis_expand = 1.2,
                      title = TRUE,
                      plot_theme = theme_metan(),
                      ...) {
-
+if(large_label != "deprecated"){
+  warning("Argument 'large_label' is deprecated as of metan 1.11.0.\nUse 'size.text.win' instead.")
+  size.text.win <- large_label
+}
   if(is.null(leg.lab)){
   leg.lab <- case_when(
     has_class(x, "gytb") ~ c("Y-Trait", "Gen"),
@@ -392,15 +426,32 @@ plot.gge <- function(x,
           axis.title = element_text(size = size.text.lab, colour = "black"))
   # Basic plot
   if (type == 1) {
-    P2 <- P1 +
+      if(has_class(model, c("gtb", "gytb"))){
+        P2 <- P1 +
+        geom_segment(xend = 0,
+                     yend = 0,
+                     size = size.line,
+                     aes(col = type),
+                     data = plotdata,
+                     show.legend = FALSE)
+      } else{
+        P2 <- P1 +
+          geom_segment(xend = 0,
+                       yend = 0,
+                       size = size.line,
+                       col = alpha(col.line, col.alpha),
+                       data = subset(plotdata, type == "environment"))
+      }
+    P2 <- P2 +
       geom_segment(xend = 0,
                    yend = 0,
                    size = size.line,
-                   col = alpha(col.env, col.alpha),
+                   col = alpha(col.line, col.alpha),
                    data = subset(plotdata, type == "environment")) +
       geom_point(aes(d1, d2, fill = type, shape = type),
                  size = size.shape,
-                 stroke = size.bor.tick,
+                 stroke = size.stroke,
+                 color = col.stroke,
                  alpha = col.alpha) +
       scale_shape_manual(labels = leg.lab,
                          values = c(shape.env, shape.gen)) +
@@ -440,16 +491,16 @@ plot.gge <- function(x,
     P2 <- P1 +
       geom_segment(aes(xend = x1_x, yend = x1_y),
                    color = col.gen,
-                   linetype = 2,
+                   linetype = line.type.gen,
                    size = size.line,
                    data = subset(plotdata, type == "genotype")) +
       geom_abline(intercept = 0,
                   slope = med2/med1,
-                  color = col.env,
+                  color = col.line,
                   size = size.line) +
       geom_abline(intercept = 0,
                   slope = -med1/med2,
-                  color = col.env,
+                  color = col.line,
                   size = size.line) +
       geom_segment(x = 0,
                    y = 0,
@@ -457,7 +508,7 @@ plot.gge <- function(x,
                    yend = med2,
                    arrow = arrow(length = unit(0.3, "cm")),
                    size = size.line,
-                   color = col.env) +
+                   color = col.line) +
       geom_text(aes(color = type,
                     label = label,
                     size = type),
@@ -519,14 +570,15 @@ plot.gge <- function(x,
                    aes(x = X1, y = X2),
                    xend = 0,
                    yend = 0,
-                   linetype = 2,
+                   linetype = line.type.gen,
                    color = col.gen,
                    size = size.line) +
       geom_point(data = subset(df_winners, win == "no"),
                  aes(d1, d2, fill = type, shape = type),
                  size = size.shape,
-                 stroke = size.bor.tick,
+                 stroke = size.stroke,
                  alpha = col.alpha,
+                 color = col.stroke,
                  show.legend = FALSE) +
       geom_text_repel(data = subset(df_winners, win == "no"),
                       aes(col = type, label = label, size = type),
@@ -534,13 +586,14 @@ plot.gge <- function(x,
       geom_point(data = subset(df_winners, win == "yes"),
                  aes(d1, d2, fill = type, shape = type),
                  size = size.shape.win,
-                 stroke = size.bor.tick,
+                 stroke = size.stroke,
+                 color = col.stroke,
                  alpha = col.alpha) +
       geom_text_repel(data = subset(df_winners, win == "yes"),
                       aes(col = type, label = label),
                       show.legend = FALSE,
                       fontface = "bold",
-                      size = large_label)
+                      size = size.text.win)
     if("genotype" %in% others$type){
       P2 <-
         P2 +
@@ -592,21 +645,22 @@ plot.gge <- function(x,
                    y = mean(coord_env[, 2]),
                    arrow = arrow(ends = "first", length = unit(0.1, "inches")),
                    size = size.line,
-                   color = col.env) +
+                   color = col.line) +
       geom_abline(intercept = 0,
                   slope = mean(coord_env[, 2])/mean(coord_env[, 1]),
-                  color = col.env,
+                  color = col.line,
                   size = size.line) +
       geom_point(aes(d1, d2, fill = type, shape = type),
                  size = size.shape,
-                 stroke = size.bor.tick,
+                 stroke = size.stroke,
+                 color = col.stroke,
                  alpha = col.alpha) +
       scale_shape_manual(labels = leg.lab, values = c(shape.env, shape.gen)) +
       scale_fill_manual(labels = leg.lab,  values = c(col.env, col.gen)) +
       geom_segment(data = subset(plotdata, type == "environment"),
                    xend = 0,
                    yend = 0,
-                   color = alpha(col.env, col.alpha),
+                   color = alpha(col.line, col.alpha),
                    size = size.line) +
       geom_text_repel(aes(col = type, label = label, size = type),
                       show.legend = FALSE,
@@ -639,18 +693,18 @@ plot.gge <- function(x,
     P2 <- P1 + geom_segment(data = subset(plotdata, type == "genotype"),
                             aes(xend = x1_x, yend = x1_y),
                             col = col.gen,
-                            linetype = "dotted") +
+                            linetype = line.type.gen) +
       geom_abline(slope = coord_env[venvironment, 2]/coord_env[venvironment, 1],
                   intercept = 0,
-                  color = alpha(col.env, col.alpha),
+                  color = alpha(col.line, col.alpha),
                   size = size.line) +
       geom_abline(slope = -coord_env[venvironment, 1]/coord_env[venvironment, 2],
                   intercept = 0,
-                  col = alpha(col.env, col.alpha),
+                  col = alpha(col.line, col.alpha),
                   size = size.line) +
       geom_segment(data = subset(plotdata, type == "environment" & label == sel_env),xend = 0,
                    yend = 0,
-                   col = alpha(col.env, col.alpha),
+                   col = alpha(col.line, col.alpha),
                    size = size.line,
                    arrow = arrow(ends = "first", length = unit(0.5, "cm"))) +
       geom_text(data = subset(plotdata, type == "genotype"),
@@ -669,6 +723,7 @@ plot.gge <- function(x,
       geom_point(data = subset(plotdata, type == "environment" & label == sel_env),
                  aes(d1, d2),
                  shape = 1,
+                 color = col.stroke,
                  size = 4)
     if (title == TRUE) {
       ggt <- ggtitle(paste("Environment:", sel_env))
@@ -688,11 +743,11 @@ plot.gge <- function(x,
                           radio = 1:8 * ((xcoord - med1)^2 + (ycoord - med2)^2)^0.5/3)
     P2 <- P1 + geom_abline(intercept = 0,
                            slope = med2/med1,
-                           col = col.env,
+                           col = col.line,
                            size = size.line) +
       geom_abline(intercept = 0,
                   slope = -med1/med2,
-                  color = col.env,
+                  color = col.line,
                   size = size.line) +
       geom_arc(data = circles,
                aes(r = radio,
@@ -710,11 +765,12 @@ plot.gge <- function(x,
                    yend = ycoord,
                    arrow = arrow(length = unit(0.15, "inches")),
                    size = size.line,
-                   color = col.env) +
+                   color = col.line) +
       geom_point(fill = col.env,
                  shape = shape.env,
                  size = size.shape,
-                 stroke = size.bor.tick,
+                 stroke = size.stroke,
+                 color = col.stroke,
                  alpha = col.alpha,
                  data = subset(plotdata, type == "environment")) +
       geom_text_repel(data = subset(plotdata, type == "environment"),
@@ -722,7 +778,10 @@ plot.gge <- function(x,
                       size = size.text.env,
                       show.legend = FALSE,
                       col = col.env) +
-      geom_point(aes(xcoord, ycoord), shape = 1, size = 4)
+      geom_point(aes(xcoord, ycoord),
+                 shape = 1,
+                 size = 4,
+                 color = col.stroke)
     if (title == TRUE) {
       ggt <- ggtitle("Ranking Environments")
     }
@@ -751,8 +810,8 @@ plot.gge <- function(x,
     plotdata$x1_y[plotdata$type == "environment"] <- x1[, 2]
     P2 <- P1 + geom_segment(data = subset(plotdata, type == "environment"),
                             aes(xend = x1_x, yend = x1_y),
-                            col = col.env,
-                            linetype = "dotted") +
+                            col = col.line,
+                            linetype = line.type.gen) +
       geom_abline(slope = coord_gen[vgenotype, 2]/coord_gen[vgenotype, 1],
                   intercept = 0,
                   color = alpha(col.gen, col.alpha),
@@ -783,6 +842,7 @@ plot.gge <- function(x,
       geom_point(data = subset(plotdata, type == "genotype" & label == sel_gen),
                  aes(d1, d2),
                  shape = 1,
+                 color = col.stroke,
                  size = 4)
     if (title == TRUE) {
       ggt <- ggtitle(paste("Genotype:", sel_gen))
@@ -835,14 +895,18 @@ plot.gge <- function(x,
                    color = col.gen) +
       geom_point(aes(d1, d2, fill = type, shape = type),
                  size = size.shape,
-                 stroke = size.bor.tick,
+                 stroke = size.stroke,
+                 color = col.stroke,
                  alpha = col.alpha) +
       scale_shape_manual(labels = leg.lab, values = c(shape.env, shape.gen)) +
       scale_fill_manual(labels = leg.lab, values = c(col.env, col.gen)) +
       geom_text_repel(aes(col = type, label = label, size = type),
                       show.legend = FALSE,
                       color = c(rep(col.gen, ngen), rep(col.env, nenv))) +
-      geom_point(aes(coordx, coordy), shape = 1, size = 3)
+      geom_point(aes(coordx, coordy),
+                 shape = 1,
+                 color = col.stroke,
+                 size = 3)
     if (title == TRUE) {
       ggt <- ggtitle("Ranking Genotypes")
     }
@@ -886,12 +950,13 @@ plot.gge <- function(x,
                 aes(label = label),
                 show.legend = FALSE,
                 col = col.gen,
-                size = large_label,
+                size = size.text.win,
                 hjust = "outward",
                 vjust = "outward") +
       geom_point(data = subset(plotdata, type == "genotype" & label %in% c(sel_gen1, sel_gen2)),
                  shape = shape.gen,
                  fill = col.gen,
+                 color = col.stroke,
                  size = size.shape) +
       plot_theme
     if (title == TRUE) {
@@ -904,13 +969,14 @@ plot.gge <- function(x,
       geom_segment(data = subset(plotdata, type == "environment"),
                    xend = 0,
                    yend = 0,
-                   col = alpha(col.env, col.alpha),
+                   col = alpha(col.line, col.alpha),
                    size = size.line) +
       geom_point(data = subset(plotdata, type == "environment"),
                  shape = shape.env,
                  fill = col.env,
                  size = size.shape,
-                 stroke = size.bor.tick,
+                 stroke = size.stroke,
+                 color = col.stroke,
                  alpha = col.alpha) +
       geom_text_repel(data = subset(plotdata, type == "environment"),
                       aes(label = label),
