@@ -153,7 +153,7 @@ NULL
 NULL
 
 .onAttach <- function(libname, pkgname) {
-  vers <-  "v1.10.0"
+  vers <-  "v1.11.0"
   packageStartupMessage("|========================================================|")
   packageStartupMessage("| Multi-Environment Trial Analysis (metan) ", vers, "       |")
   packageStartupMessage("| Author: Tiago Olivoto                                  |")
@@ -188,5 +188,6 @@ if (getRversion() >= "2.15.1") {
       "intercept", "lower", "upper", "pred_ols", "res_ammi", "res_ols", "pattern",
       "replacement", "comparison", "group1", "group2", "p.adj", "term", "rel_freq",
       "variable", "Model", "level", "RESIDUAL", "MGIDI", "sd.amo", "SD", "SG", "data.x",
-      "data.y", "sense", "win", "where", "test", "FG", "SI", "ACV", "SDperc", "MEGA_ENV"))
+      "data.y", "sense", "win", "where", "test", "FG", "SI", "ACV", "SDperc", "MEGA_ENV",
+      "group", "hjust", "theta", "vjust", "x_raw", "y_raw"))
   }
